'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _reactIntl = require('react-intl');

exports.default = configContext => {
  var _configContext$inputC = configContext.inputComponents;
  const AutocompleteInput = _configContext$inputC.AutocompleteInput,
        CompoundInput = _configContext$inputC.CompoundInput,
        DateInput = _configContext$inputC.DateInput,
        TextInput = _configContext$inputC.TextInput,
        TermPickerInput = _configContext$inputC.TermPickerInput;
  const config = configContext.configHelpers.configKey;
  const DATA_TYPE_DATE = configContext.dataTypes.DATA_TYPE_DATE;


  return {
    'ns2:collectionobjects_culturalcare': {
      [config]: {
        service: {
          // Should have been domain/culturalcare, but this was set incorrectly in 4.x.
          ns: 'http://collectionspace.org/services/collectionobject/domain/collectionobject'
        }
      },
      culturalCareNotes: {
        [config]: {
          view: {
            type: CompoundInput
          }
        },
        culturalCareNote: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.collectionobjects_culturalcare.culturalCareNote.name',
                'defaultMessage': 'Cultural care note'
              }
            }),
            repeating: true,
            view: {
              type: TextInput,
              props: {
                multiline: true
              }
            }
          }
        }
      },
      accessLimitationsGroupList: {
        [config]: {
          view: {
            type: CompoundInput
          }
        },
        accessLimitationsGroup: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.collectionobjects_culturalcare.accessLimitationsGroup.name',
                'defaultMessage': 'Access limitation'
              }
            }),
            repeating: true,
            view: {
              type: CompoundInput,
              props: {
                tabular: true
              }
            }
          },
          limitationType: {
            [config]: {
              messages: (0, _reactIntl.defineMessages)({
                fullName: {
                  'id': 'field.collectionobjects_culturalcare.limitationType.fullName',
                  'defaultMessage': 'Access limitation type'
                },
                name: {
                  'id': 'field.collectionobjects_culturalcare.limitationType.name',
                  'defaultMessage': 'Type'
                }
              }),
              view: {
                type: TermPickerInput,
                props: {
                  source: 'limitationtype'
                }
              }
            }
          },
          limitationLevel: {
            [config]: {
              messages: (0, _reactIntl.defineMessages)({
                fullName: {
                  'id': 'field.collectionobjects_culturalcare.limitationLevel.fullName',
                  'defaultMessage': 'Access limitation level'
                },
                name: {
                  'id': 'field.collectionobjects_culturalcare.limitationLevel.name',
                  'defaultMessage': 'Level'
                }
              }),
              view: {
                type: TermPickerInput,
                props: {
                  source: 'limitationlevel'
                }
              }
            }
          },
          limitationDetails: {
            [config]: {
              messages: (0, _reactIntl.defineMessages)({
                fullName: {
                  'id': 'field.collectionobjects_culturalcare.limitationDetails.fullName',
                  'defaultMessage': 'Access limitation detail'
                },
                name: {
                  'id': 'field.collectionobjects_culturalcare.limitationDetails.name',
                  'defaultMessage': 'Detail'
                }
              }),
              view: {
                type: TextInput
              }
            }
          },
          requester: {
            [config]: {
              messages: (0, _reactIntl.defineMessages)({
                fullName: {
                  'id': 'field.collectionobjects_culturalcare.requester.fullName',
                  'defaultMessage': 'Access limitation requestor'
                },
                name: {
                  'id': 'field.collectionobjects_culturalcare.requester.name',
                  'defaultMessage': 'Requestor'
                }
              }),
              view: {
                type: AutocompleteInput,
                props: {
                  source: 'person/local'
                }
              }
            }
          },
          requestOnBehalfOf: {
            [config]: {
              messages: (0, _reactIntl.defineMessages)({
                fullName: {
                  'id': 'field.collectionobjects_culturalcare.requestOnBehalfOf.fullName',
                  'defaultMessage': 'Access limitation requested on behalf of'
                },
                name: {
                  'id': 'field.collectionobjects_culturalcare.requestOnBehalfOf.name',
                  'defaultMessage': 'On behalf of'
                }
              }),
              view: {
                type: AutocompleteInput,
                props: {
                  source: 'organization/local'
                }
              }
            }
          },
          requestDate: {
            [config]: {
              dataType: DATA_TYPE_DATE,
              messages: (0, _reactIntl.defineMessages)({
                fullName: {
                  'id': 'field.collectionobjects_culturalcare.requestDate.fullName',
                  'defaultMessage': 'Access limitation request date'
                },
                name: {
                  'id': 'field.collectionobjects_culturalcare.requestDate.name',
                  'defaultMessage': 'Date'
                }
              }),
              view: {
                type: DateInput
              }
            }
          }
        }
      }
    }
  };
};